@@ -12,9 +12,8 @@ test_that("Test csu_group_cases: 1",{
     df_ICD = ICD_group_GLOBOCAN,
     var_ICD  ="site") 
 
+  #saveRDS(output_test,"csu_group_cases_test1.rds")
   expect_test <- readRDS(system.file("testdata","csu_group_cases_test1.rds",package="Rcan"))
-  saveRDS(output_test,"csu_group_cases_test1.rds")
-
   #test
   expect_equal(output_test, expect_test)
 })
@@ -43,6 +42,7 @@ test_that("Test csu_merge_cases_pop: 1",{
     var_py = "pop",
     group_by = c("sex"))
 
+  saveRDS(output_test,"csu_merge_cases_pop1.rds")
   expect_test <- readRDS(system.file("testdata","csu_merge_cases_pop1.rds",package="Rcan"))
   #test
   expect_equal(output_test, expect_test)
